@@ -15,7 +15,7 @@ Readonly::Array our @EXPORT_OK => qw(set_params set_params_pub set_split_params
 	split_params);
 
 # Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Set parameters to user values.
 sub set_params {
@@ -248,20 +248,15 @@ Class::Utils - Class utilities.
  # Modules.
  use Class::Utils qw(split_params);
 
- # Hash reference with default parameters.
- my $self = {
-        'foo' => undef,
- };
-
  # Example parameters.
  my @params = qw(foo bar bad value);
 
  # Set bad params.
- my ($object_params_ar, $other_params_ar) = split_params(['foo'], @params);
+ my ($main_params_ar, $other_params_ar) = split_params(['foo'], @params);
 
  # Print out.
  print "Main params:\n";
- print "* ".(join ': ', @{$object_params_ar});
+ print "* ".(join ': ', @{$main_params_ar});
  print "\n";
  print "Other params:\n";
  print "* ".(join ': ', @{$other_params_ar});
@@ -292,10 +287,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © Michal Špaček 2011-2015
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
